Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(299)

Unified Diff: device/gamepad/gamepad_provider.h

Issue 2852803002: Remove base::SharedMemory::ShareToProcess. (Closed)
Patch Set: Compile error. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/pepper/pepper_platform_audio_output_dev.cc ('k') | device/gamepad/gamepad_provider.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/gamepad/gamepad_provider.h
diff --git a/device/gamepad/gamepad_provider.h b/device/gamepad/gamepad_provider.h
index 6dea63ac52744b022165d3f739307548277bc847..063e8a4bf433937b55c0ddded05a3066a918ccb4 100644
--- a/device/gamepad/gamepad_provider.h
+++ b/device/gamepad/gamepad_provider.h
@@ -51,10 +51,8 @@ class DEVICE_GAMEPAD_EXPORT GamepadProvider
~GamepadProvider() override;
- // Returns the shared memory handle of the gamepad data duplicated into the
- // given process.
- base::SharedMemoryHandle GetSharedMemoryHandleForProcess(
- base::ProcessHandle renderer_process);
+ // Returns a duplicate of the shared memory handle of the gamepad data.
+ base::SharedMemoryHandle DuplicateSharedMemoryHandle();
// Returns a new mojo::ScopedSharedBufferHandle of the gamepad data.
mojo::ScopedSharedBufferHandle GetSharedBufferHandle();
« no previous file with comments | « content/renderer/pepper/pepper_platform_audio_output_dev.cc ('k') | device/gamepad/gamepad_provider.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698